resttools.yield_groups_of_rests_in_sequence
===========================================

.. autofunction:: abjad.tools.resttools.yield_groups_of_rests_in_sequence.yield_groups_of_rests_in_sequence
   :noindex:
